@@ -211,7 +211,7 @@ gnome_vfs_seek_position_get_type (void)
 }
 
 
-/* enumerations from "gnome-vfs-mime-handlers.h" */
+/* enumerations from "gnome-vfs-mime-deprecated.h" */
 GType
 gnome_vfs_mime_action_type_get_type (void)
 {
@@ -228,6 +228,8 @@ gnome_vfs_mime_action_type_get_type (void)
   return etype;
 }
 
+
+/* enumerations from "gnome-vfs-mime-handlers.h" */
 GType
 gnome_vfs_mime_application_argument_type_get_type (void)
 {
@@ -245,6 +247,24 @@ gnome_vfs_mime_application_argument_type_get_type (void)
 }
 
 
+/* enumerations from "gnome-vfs-mime-utils.h" */
+GType
+gnome_vfs_mime_equivalence_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GNOME_VFS_MIME_UNRELATED, "GNOME_VFS_MIME_UNRELATED", "unrelated" },
+      { GNOME_VFS_MIME_IDENTICAL, "GNOME_VFS_MIME_IDENTICAL", "identical" },
+      { GNOME_VFS_MIME_PARENT, "GNOME_VFS_MIME_PARENT", "parent" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GnomeVFSMimeEquivalence", values);
+  }
+  return etype;
+}
+
+
 /* enumerations from "gnome-vfs-monitor.h" */
 GType
 gnome_vfs_monitor_type_get_type (void)
@@ -334,6 +354,10 @@ gnome_vfs_result_get_type (void)
       { GNOME_VFS_ERROR_NO_HANDLER, "GNOME_VFS_ERROR_NO_HANDLER", "error-no-handler" },
       { GNOME_VFS_ERROR_PARSE, "GNOME_VFS_ERROR_PARSE", "error-parse" },
       { GNOME_VFS_ERROR_LAUNCH, "GNOME_VFS_ERROR_LAUNCH", "error-launch" },
+      { GNOME_VFS_ERROR_TIMEOUT, "GNOME_VFS_ERROR_TIMEOUT", "error-timeout" },
+      { GNOME_VFS_ERROR_NAMESERVER, "GNOME_VFS_ERROR_NAMESERVER", "error-nameserver" },
+      { GNOME_VFS_ERROR_LOCKED, "GNOME_VFS_ERROR_LOCKED", "error-locked" },
+      { GNOME_VFS_ERROR_DEPRECATED_FUNCTION, "GNOME_VFS_ERROR_DEPRECATED_FUNCTION", "error-deprecated-function" },
       { GNOME_VFS_NUM_ERRORS, "GNOME_VFS_NUM_ERRORS", "num-errors" },
       { 0, NULL, NULL }
     };
@@ -355,6 +379,7 @@ gnome_vfs_module_callback_full_authentication_flags_get_type (void)
       { GNOME_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_NEED_USERNAME, "GNOME_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_NEED_USERNAME", "need-username" },
       { GNOME_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_NEED_DOMAIN, "GNOME_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_NEED_DOMAIN", "need-domain" },
       { GNOME_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_SAVING_SUPPORTED, "GNOME_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_SAVING_SUPPORTED", "saving-supported" },
+      { GNOME_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_ANON_SUPPORTED, "GNOME_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_ANON_SUPPORTED", "anon-supported" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("GnomeVFSModuleCallbackFullAuthenticationFlags", values);
@@ -362,6 +387,20 @@ gnome_vfs_module_callback_full_authentication_flags_get_type (void)
   return etype;
 }
 
+GType
+gnome_vfs_module_callback_full_authentication_out_flags_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { GNOME_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_OUT_ANON_SELECTED, "GNOME_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_OUT_ANON_SELECTED", "selected" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static ("GnomeVFSModuleCallbackFullAuthenticationOutFlags", values);
+  }
+  return etype;
+}
+
 
 /* enumerations from "gnome-vfs-utils.h" */
 GType
@@ -381,6 +420,55 @@ gnome_vfs_make_uri_dirs_get_type (void)
 }
 
 
+/* enumerations from "gnome-vfs-volume.h" */
+GType
+gnome_vfs_device_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GNOME_VFS_DEVICE_TYPE_UNKNOWN, "GNOME_VFS_DEVICE_TYPE_UNKNOWN", "unknown" },
+      { GNOME_VFS_DEVICE_TYPE_AUDIO_CD, "GNOME_VFS_DEVICE_TYPE_AUDIO_CD", "audio-cd" },
+      { GNOME_VFS_DEVICE_TYPE_VIDEO_DVD, "GNOME_VFS_DEVICE_TYPE_VIDEO_DVD", "video-dvd" },
+      { GNOME_VFS_DEVICE_TYPE_HARDDRIVE, "GNOME_VFS_DEVICE_TYPE_HARDDRIVE", "harddrive" },
+      { GNOME_VFS_DEVICE_TYPE_CDROM, "GNOME_VFS_DEVICE_TYPE_CDROM", "cdrom" },
+      { GNOME_VFS_DEVICE_TYPE_FLOPPY, "GNOME_VFS_DEVICE_TYPE_FLOPPY", "floppy" },
+      { GNOME_VFS_DEVICE_TYPE_ZIP, "GNOME_VFS_DEVICE_TYPE_ZIP", "zip" },
+      { GNOME_VFS_DEVICE_TYPE_JAZ, "GNOME_VFS_DEVICE_TYPE_JAZ", "jaz" },
+      { GNOME_VFS_DEVICE_TYPE_NFS, "GNOME_VFS_DEVICE_TYPE_NFS", "nfs" },
+      { GNOME_VFS_DEVICE_TYPE_AUTOFS, "GNOME_VFS_DEVICE_TYPE_AUTOFS", "autofs" },
+      { GNOME_VFS_DEVICE_TYPE_CAMERA, "GNOME_VFS_DEVICE_TYPE_CAMERA", "camera" },
+      { GNOME_VFS_DEVICE_TYPE_MEMORY_STICK, "GNOME_VFS_DEVICE_TYPE_MEMORY_STICK", "memory-stick" },
+      { GNOME_VFS_DEVICE_TYPE_SMB, "GNOME_VFS_DEVICE_TYPE_SMB", "smb" },
+      { GNOME_VFS_DEVICE_TYPE_APPLE, "GNOME_VFS_DEVICE_TYPE_APPLE", "apple" },
+      { GNOME_VFS_DEVICE_TYPE_MUSIC_PLAYER, "GNOME_VFS_DEVICE_TYPE_MUSIC_PLAYER", "music-player" },
+      { GNOME_VFS_DEVICE_TYPE_WINDOWS, "GNOME_VFS_DEVICE_TYPE_WINDOWS", "windows" },
+      { GNOME_VFS_DEVICE_TYPE_LOOPBACK, "GNOME_VFS_DEVICE_TYPE_LOOPBACK", "loopback" },
+      { GNOME_VFS_DEVICE_TYPE_NETWORK, "GNOME_VFS_DEVICE_TYPE_NETWORK", "network" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GnomeVFSDeviceType", values);
+  }
+  return etype;
+}
+
+GType
+gnome_vfs_volume_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GNOME_VFS_VOLUME_TYPE_MOUNTPOINT, "GNOME_VFS_VOLUME_TYPE_MOUNTPOINT", "mountpoint" },
+      { GNOME_VFS_VOLUME_TYPE_VFS_MOUNT, "GNOME_VFS_VOLUME_TYPE_VFS_MOUNT", "vfs-mount" },
+      { GNOME_VFS_VOLUME_TYPE_CONNECTED_SERVER, "GNOME_VFS_VOLUME_TYPE_CONNECTED_SERVER", "connected-server" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GnomeVFSVolumeType", values);
+  }
+  return etype;
+}
+
+
 /* enumerations from "gnome-vfs-xfer.h" */
 GType
 gnome_vfs_xfer_options_get_type (void)
